@@ -9,7 +9,7 @@ pub enum OckamError {
     ConsistencyError,
     ComplexEventsAreNotSupported,
     EventIdDoesNotMatch,
-    ProfileIdDoesNotMatch,
+    IdentityIdDoesNotMatch,
     EmptyChange,
     ContactNotFound,
     EventNotFound,
@@ -22,6 +22,7 @@ pub enum OckamError {
     SecureChannelVerificationFailed,
     SecureChannelCannotBeAuthenticated,
     NoSuchProtocol,
+    SystemAddressNotBound,
 }
 
 impl OckamError {
